package org.apache.bcel.classfile;

import java.io.DataInput;
import java.io.DataOutputStream;
import java.io.IOException;
import java.util.Arrays;
import java.util.Iterator;
import java.util.stream.Stream;

public class MethodParameters extends Attribute implements Iterable<MethodParameter> {
   private static final MethodParameter[] EMPTY_METHOD_PARAMETER_ARRAY = new MethodParameter[0];
   private MethodParameter[] parameters;

   MethodParameters(int nameIndex, int length, DataInput input, ConstantPool constantPool) throws IOException {
      super((byte)21, nameIndex, length, constantPool);
      this.parameters = EMPTY_METHOD_PARAMETER_ARRAY;
      int parameterCount = input.readUnsignedByte();
      this.parameters = new MethodParameter[parameterCount];

      for(int i = 0; i < parameterCount; ++i) {
         this.parameters[i] = new MethodParameter(input);
      }

   }

   public void accept(Visitor v) {
      v.visitMethodParameters(this);
   }

   public Attribute copy(ConstantPool constantPool) {
      MethodParameters c = (MethodParameters)this.clone();
      c.parameters = new MethodParameter[this.parameters.length];
      Arrays.setAll(c.parameters, (i) -> {
         return this.parameters[i].copy();
      });
      c.setConstantPool(constantPool);
      return c;
   }

   public void dump(DataOutputStream file) throws IOException {
      super.dump(file);
      file.writeByte(this.parameters.length);
      MethodParameter[] var2 = this.parameters;
      int var3 = var2.length;

      for(int var4 = 0; var4 < var3; ++var4) {
         MethodParameter parameter = var2[var4];
         parameter.dump(file);
      }

   }

   public MethodParameter[] getParameters() {
      return this.parameters;
   }

   public Iterator<MethodParameter> iterator() {
      return Stream.of(this.parameters).iterator();
   }

   public void setParameters(MethodParameter[] parameters) {
      this.parameters = parameters;
   }
}
